package org.eclipse.persistence.example.jaxb;

import java.io.File;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.Marshaller;
import javax.xml.bind.Unmarshaller;

import javax.xml.transform.stream.StreamSource;

import org.example.customer_example.CustomerType;
import org.example.customer_example.PhoneNumber;
import org.example.customer_example.ObjectFactory;

public class Example {

    public static void main(String[] args) throws Exception {
        // = Create the JAXBContext ============================================
        JAXBContext jaxbContext = JAXBContext.newInstance("org.example.customer_example");

        // = Unmarshal the XML Document to a Java object =======================
        File file = new File("config/Customer-data.xml");
        Unmarshaller unmarshaller = jaxbContext.createUnmarshaller();
        StreamSource source = new StreamSource(file);
        JAXBElement customerElement = unmarshaller.unmarshal(source, CustomerType.class);
        CustomerType customer = (CustomerType) customerElement.getValue();

        // = Modify the ShippingAddress ZipCode ================================
        customer.getContactInfo().getShippingAddress().setZipCode("27601");

        // = Add a new PhoneNumber =============================================
        PhoneNumber homePhoneNumber  = new ObjectFactory().createPhoneNumber();
        homePhoneNumber.setNumberType("home");
        homePhoneNumber.setValue("(613) 555-3333");
        customer.getContactInfo().getPhoneNumber().add(homePhoneNumber);

        // = Remove all "cell" PhoneNumbers ====================================
        ArrayList phoneNumbersToRemove = new ArrayList();
        List phoneNumbers = customer.getContactInfo().getPhoneNumber();
        Iterator it = phoneNumbers.iterator();
        while (it.hasNext()) {
            PhoneNumber phoneNumber = (PhoneNumber) it.next();
            if (phoneNumber.getNumberType().equals("cell")) {
                phoneNumbersToRemove.add(phoneNumber);
            }
        }
        phoneNumbers.removeAll(phoneNumbersToRemove);

        // = Marshal the Java object back to an XML Document ===================
        Marshaller marshaller = jaxbContext.createMarshaller();
        marshaller.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, Boolean.TRUE);
        marshaller.marshal(customerElement, System.out);
    }

}