package org.eclipse.persistence.example.moxy;

import java.io.File;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.Marshaller;
import javax.xml.bind.Unmarshaller;

import org.eclipse.persistence.example.moxy.model.Customer;
import org.eclipse.persistence.example.moxy.model.PhoneNumber;

public class Example {

    public static void main(String[] args) throws Exception {
        // = Create the JAXBContext ============================================
        JAXBContext jaxbContext = JAXBContext.newInstance("org.eclipse.persistence.example.moxy.model");

        // = Unmarshal the XML Document to a Java object =======================
        File file = new File("config/Customer-data.xml");
        Unmarshaller unmarshaller = jaxbContext.createUnmarshaller();
        Customer customer = (Customer) unmarshaller.unmarshal(file);

        // = Modify the ShippingAddress PostalCode =============================
        customer.getShippingAddress().setPostalCode("27601");

        // = Add a new PhoneNumber =============================================
        PhoneNumber homePhoneNumber = new PhoneNumber();
        homePhoneNumber.setNumberType("home");
        homePhoneNumber.setNumber("(613) 555-3333");
        customer.getPhoneNumbers().add(homePhoneNumber);

        // = Remove all "cell" PhoneNumbers ====================================
        ArrayList phoneNumbersToRemove = new ArrayList();
        List phoneNumbers = customer.getPhoneNumbers();
        Iterator it = phoneNumbers.iterator();
        while (it.hasNext()) {
            PhoneNumber phoneNumber = (PhoneNumber) it.next();
            if (phoneNumber.getNumberType().equals("cell")) {
                phoneNumbersToRemove.add(phoneNumber);
            }
        }
        phoneNumbers.removeAll(phoneNumbersToRemove);

        // = Marshal the Java object back to an XML Document ===================
        Marshaller marshaller = jaxbContext.createMarshaller();
        marshaller.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, Boolean.TRUE);
        marshaller.marshal(customer, System.out);
    }

}