package org.eclipse.persistence.example.sdo.dynamicapi;

import java.io.FileInputStream;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import commonj.sdo.DataObject;
import commonj.sdo.helper.DataFactory;
import commonj.sdo.helper.XMLDocument;
import commonj.sdo.helper.XSDHelper;
import commonj.sdo.helper.XMLHelper;

public class Example {

    public static void main(String[] args) throws Exception {
        // = Initialize the types ==============================================
        FileInputStream xsdInputStream = new FileInputStream("config/Customer.xsd");
        XSDHelper.INSTANCE.define(xsdInputStream, null);

        // = Unmarshal the XML document ========================================
        FileInputStream xmlInputStream = new FileInputStream("config/Customer-data.xml");
        XMLDocument xmlDocument = XMLHelper.INSTANCE.load(xmlInputStream);
        DataObject customerDO = xmlDocument.getRootObject(); 

        // = Turn on change tracking ===========================================
        customerDO.getChangeSummary().beginLogging();

        System.out.println("HERE");

        // = Modify the ShippingAddress ZipCode ================================
        DataObject addressDO = customerDO.getDataObject("contact-info").getDataObject("shipping-address");
        addressDO.set("zip-code", "27601");

        // = Add a new PhoneNumber =============================================
        DataObject newPhoneNumberDO = DataFactory.INSTANCE.create("http://www.example.org/customer-example", "phone-number");
        newPhoneNumberDO.set("number-type", "home");
        newPhoneNumberDO.set("value", "(613) 555-3333");
        customerDO.getList("contact-info/phone-number").add(newPhoneNumberDO); 

        // = Remove all "cell" PhoneNumbers ====================================
        ArrayList phoneNumbersToRemove = new ArrayList();
        List phoneNumbers = customerDO.getDataObject("contact-info").getList("phone-number");
        Iterator it = phoneNumbers.iterator();
        while (it.hasNext()) {
            DataObject phoneNumberDO = (DataObject) it.next();
            if (phoneNumberDO.get("number-type").equals("cell")) {
                phoneNumbersToRemove.add(phoneNumberDO);
            }
        }
        phoneNumbers.removeAll(phoneNumbersToRemove);
        
        // = Turn off change tracking ==========================================
        customerDO.getChangeSummary().endLogging();
        
        // = Marshal the Java object back to an XML document ===================
        XMLHelper.INSTANCE.save(xmlDocument, System.out, null);
    }

}